<?php

/**
 * @file
 * Contains Drupal\lockr\LockrClient.
 */

namespace Drupal\lockr;

use Lockr\KeyClient;
use Lockr\Lockr;
use Lockr\SiteClient;
use Symfony\Component\DependencyInjection\ContainerInterface;

class LockrClient implements LockrClientInterface {

  /**
   * @var Lockr
   */
  protected $client = NULL;

  /**
   * @var LockrPartnerInterface
   */
  protected $partner;

  /**
   * Construct a new LockrClient.
   *
   * @param LockrPartnerInterface $partner
   *   The partner factory.
   */
  public function __construct(LockrPartnerInterface $partner) {
    $this->partner = $partner->getPartner();
  }

  /**
   * Create a new LockrClient instance.
   *
   * @param ContainerInterface $container
   *   The dependency injection container.
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('lockr.partner'));
  }

  /**
   * {@inheritdoc}
   */
  public function exists() {
    $client = $this->getSiteClient();
    if ($client === NULL) {
      return NULL;
    }

    return $client->exists();
  }

  /**
   * {@inheritdoc}
   */
  public function register($email, $password = NULL, $name = NULL) {
    $client = $this->getSiteClient();
    if ($client === NULL) {
      return NULL;
    }

    return $client->register($email, $password, $name);
  }

  /**
   * {@inheritdoc}
   */
  public function getKey($name, $encoded = NULL) {
    $client = $this->getKeyClient();
    if ($client === NULL) {
      return NULL;
    }

    return $client->encrypted($encoded)->get($name);
  }

  /**
   * {@inheritdoc}
   */
  public function createKey($key_size) {
    $client = $this->getKeyClient();
    if ($client === NULL) {
      return NULL;
    }

    return $client->create($key_size);
  }

  /**
   * {@inheritdoc}
   */
  public function setKey($name, $value, $label = NULL, $encoded = NULL) {
    $client = $this->getKeyClient();
    if ($client === NULL) {
      return NULL;
    }

    return $client->encrypted()->set($name, $value, $label, $encoded);
  }

  /**
   * {@inheritdoc}
   */
  public function deleteKey($name) {
    $client = $this->getKeyClient();
    if ($client === NULL) {
      return NULL;
    }

    $client->delete($name);
  }

  public function getClient() {
    if ($this->client === NULL) {
      if ($this->partner === NULL) {
        return NULL;
      }
      $this->client = Lockr::create($this->partner);
    }

    return $this->client;
  }

  public function getSiteClient() {
    $client = $this->getClient();
    if ($client === NULL) {
      return NULL;
    }

    return new SiteClient($client);
  }

  public function getKeyClient() {
    $client = $this->getClient();
    if ($client === NULL) {
      return NULL;
    }

    return new KeyClient($client);
  }

}
