<?php

/**
 * @file
 * Contains Drupal\lockr\LockrClientInterface.
 */

namespace Drupal\lockr;

interface LockrClientInterface {

  /**
   * Determines the site status.
   *
   * @return array
   *   A two element array, the first whether the site is registered,
   *   the second whether the site is able to use the API.
   */
  public function exists();

  /**
   * Register the site.
   *
   * @param string $email
   *   The email to register with.
   * @param string $password
   *   (optional) The password to use if login is required.
   * @param string $name
   *   (optional) The human readable site name.
   */
  public function register($email, $password = NULL, $name = NULL);

  /**
   * Get a key from Lockr.
   *
   * @param string $name
   *   The key name to get.
   * @param string $encoded
   *   (optional) The encryption data, if the key is encrypted.
   *
   * @return string
   *   The key value.
   */
  public function getKey($name, $encoded = NULL);

  /**
   * Create a key in lockr.
   *
   * @param int $key_size
   *   The size of the created key.
   *
   * @return string
   *   The created key value.
   */
  public function createKey($key_size);

  /**
   * Set a key in Lockr.
   *
   * @param string $name
   *   The key name to set.
   * @param string $value
   *   The key value to set.
   * @param string $label
   *   (optional) The human readable name.
   * @param string $encoded
   *   (optional) The encryption data used to encrypt the key.
   */
  public function setKey($name, $value, $label = NULL, $encoded = NULL);

  /**
   * Delete a key in Lockr.
   *
   * @param string $name
   *   The key name to delete.
   */
  public function deleteKey($name);

}
