<?php

/**
 * @file
 * Contains Drupal\lockr\LockrPartner.
 */

namespace Drupal\lockr;

use Drupal\Core\State\StateInterface;

use Lockr\Partner;

class LockrPartner implements LockrPartnerInterface {

  protected $state;

  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public function getPartner() {
    $partner = $this->getPartnerName();
    $cert = $this->getPartnerCert();

    if ($cert === NULL) {
      return NULL;
    }

    return new Partner(
      $cert,
      $partner,
      $this->state->get('lockr.region', 'us')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getPartnerName() {
    $partner = $this->state->get('lockr.partner');

    if ($partner !== NULL) {
      return $partner;
    }

    if (defined('PANTHEON_BINDING')) {
      return 'pantheon';
    }

    return 'custom';
  }

  /**
   * {@inheritdoc}
   */
  public function getPartnerCert() {
    if (defined('PANTHEON_BINDING')) {
      return '/srv/bindings/' . PANTHEON_BINDING . '/certs/binding.pem';
    }

    return $this->state->get('lockr.cert');
  }

}
